@@ -17,11 +17,11 @@
 #ifndef _FETCHER_H_INCLUDED_
 #define _FETCHER_H_INCLUDED_
 
-#include "safesysstat.h"
 #include <string>
 #include <memory>
 
 #include "rcldoc.h"
+#include "pathut.h"
 
 class RclConfig;
 
@@ -51,7 +51,7 @@ public:
         enum RawDocKind {RDK_FILENAME, RDK_DATA, RDK_DATADIRECT};
         RawDocKind kind;
         std::string data; // Doc data or file name
-        struct stat st; // Only used if RDK_FILENAME
+        struct PathStat st; // Only used if RDK_FILENAME
     };
 
     /** 
@@ -75,7 +75,7 @@ public:
     virtual bool makesig(RclConfig* cnf, const Rcl::Doc& idoc,
                          std::string& sig) = 0;
     enum Reason{FetchOk, FetchNotExist, FetchNoPerm, FetchOther};
-    virtual Reason testAccess(RclConfig* cnf, const Rcl::Doc& idoc) {
+    virtual Reason testAccess(RclConfig*, const Rcl::Doc&) {
         return FetchOther;
     }
     virtual ~DocFetcher() {}
